@@ -33,7 +33,7 @@ from google.cloud.batch_v1 import (
     Task,
 )
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
@@ -147,19 +147,18 @@ class CloudBatchHook(GoogleBaseHook):
                 status: JobStatus.State = job.status.state
                 if status == JobStatus.State.SUCCEEDED:
                     return job
-                elif status == JobStatus.State.FAILED:
+                if status == JobStatus.State.FAILED:
                     message = (
                         "Unexpected error in the operation: "
                         "Batch job with name {job_name} has failed its execution."
                     )
                     raise AirflowException(message)
-                elif status == JobStatus.State.DELETION_IN_PROGRESS:
+                if status == JobStatus.State.DELETION_IN_PROGRESS:
                     message = (
                         "Unexpected error in the operation: Batch job with name {job_name} is being deleted."
                     )
                     raise AirflowException(message)
-                else:
-                    time.sleep(polling_period_seconds)
+                time.sleep(polling_period_seconds)
             except Exception as e:
                 self.log.exception("Exception occurred while checking for job completion.")
                 raise e
