@@ -76,7 +76,7 @@ with DAG(
         py_requirements=["apache-beam[gcp]==2.67.0"],
         py_interpreter="python3",
         py_system_site_packages=False,
-        dataflow_config={"location": LOCATION, "job_name": "start_python_job"},
+        dataflow_config={"location": LOCATION, "job_name": "start_python_job", "max_num_workers": 1},
     )
     # [END howto_operator_start_python_job]
 
@@ -91,7 +91,7 @@ with DAG(
         py_requirements=["apache-beam[gcp]==2.67.0"],
         py_interpreter="python3",
         py_system_site_packages=False,
-        dataflow_config={"location": LOCATION, "job_name": "start_python_deferrable"},
+        dataflow_config={"location": LOCATION, "job_name": "start_python_deferrable", "max_num_workers": 1},
         deferrable=True,
     )
 
