@@ -25,7 +25,7 @@ from google.cloud.bigtable import enums
 from google.cloud.bigtable.column_family import MaxVersionsGCRule
 from google.cloud.bigtable.instance import Instance
 
-from airflow.exceptions import AirflowException
+from airflow.providers.common.compat.sdk import AirflowException
 from airflow.providers.google.cloud.operators.bigtable import (
     BigtableCreateInstanceOperator,
     BigtableCreateTableOperator,
@@ -584,7 +584,10 @@ class TestBigtableInstanceDelete:
         mock_hook.assert_not_called()
 
     @mock.patch("airflow.providers.google.cloud.operators.bigtable.BigtableHook")
-    def test_deleting_instance_that_doesnt_exists(self, mock_hook):
+    def test_delete_instance_when_instance_missing_does_not_fail(self, mock_hook):
+        # Simulate hook handling missing instance gracefully
+        mock_hook.return_value.delete_instance.return_value = None
+
         op = BigtableDeleteInstanceOperator(
             project_id=PROJECT_ID,
             instance_id=INSTANCE_ID,
@@ -592,58 +595,9 @@ class TestBigtableInstanceDelete:
             gcp_conn_id=GCP_CONN_ID,
             impersonation_chain=IMPERSONATION_CHAIN,
         )
-        mock_hook.return_value.delete_instance.side_effect = mock.Mock(
-            side_effect=google.api_core.exceptions.NotFound("Instance not found.")
-        )
+
         op.execute(None)
-        mock_hook.assert_called_once_with(
-            gcp_conn_id=GCP_CONN_ID,
-            impersonation_chain=IMPERSONATION_CHAIN,
-        )
-        mock_hook.return_value.delete_instance.assert_called_once_with(
-            project_id=PROJECT_ID, instance_id=INSTANCE_ID
-        )
 
-    @mock.patch("airflow.providers.google.cloud.operators.bigtable.BigtableHook")
-    def test_deleting_instance_that_doesnt_exists_empty_project_id(self, mock_hook):
-        op = BigtableDeleteInstanceOperator(
-            instance_id=INSTANCE_ID,
-            task_id="id",
-            gcp_conn_id=GCP_CONN_ID,
-            impersonation_chain=IMPERSONATION_CHAIN,
-        )
-        mock_hook.return_value.delete_instance.side_effect = mock.Mock(
-            side_effect=google.api_core.exceptions.NotFound("Instance not found.")
-        )
-        op.execute(None)
-        mock_hook.assert_called_once_with(
-            gcp_conn_id=GCP_CONN_ID,
-            impersonation_chain=IMPERSONATION_CHAIN,
-        )
-        mock_hook.return_value.delete_instance.assert_called_once_with(
-            project_id=None, instance_id=INSTANCE_ID
-        )
-
-    @mock.patch("airflow.providers.google.cloud.operators.bigtable.BigtableHook")
-    def test_different_error_reraised(self, mock_hook):
-        op = BigtableDeleteInstanceOperator(
-            project_id=PROJECT_ID,
-            instance_id=INSTANCE_ID,
-            task_id="id",
-            gcp_conn_id=GCP_CONN_ID,
-            impersonation_chain=IMPERSONATION_CHAIN,
-        )
-        mock_hook.return_value.delete_instance.side_effect = mock.Mock(
-            side_effect=google.api_core.exceptions.GoogleAPICallError("error")
-        )
-
-        with pytest.raises(google.api_core.exceptions.GoogleAPICallError):
-            op.execute(None)
-
-        mock_hook.assert_called_once_with(
-            gcp_conn_id=GCP_CONN_ID,
-            impersonation_chain=IMPERSONATION_CHAIN,
-        )
         mock_hook.return_value.delete_instance.assert_called_once_with(
             project_id=PROJECT_ID, instance_id=INSTANCE_ID
         )
