@@ -514,21 +514,19 @@ class TestPubSubPullOperator:
 
     @pytest.mark.db_test
     @mock.patch("airflow.providers.google.cloud.operators.pubsub.PubSubHook")
-    def test_execute_deferred(self, mock_hook, create_task_instance_of_operator):
+    def test_execute_deferred(self, mock_hook):
         """
         Asserts that a task is deferred and a PubSubPullOperator will be fired
         when the PubSubPullOperator is executed with deferrable=True.
         """
-        ti = create_task_instance_of_operator(
-            PubSubPullOperator,
-            dag_id="dag_id",
+        task = PubSubPullOperator(
             task_id=TASK_ID,
             project_id=TEST_PROJECT,
             subscription=TEST_SUBSCRIPTION,
             deferrable=True,
         )
         with pytest.raises(TaskDeferred) as _:
-            ti.task.execute(mock.MagicMock())
+            task.execute(mock.MagicMock())
 
     @mock.patch("airflow.providers.google.cloud.operators.pubsub.PubSubHook")
     def test_get_openlineage_facets(self, mock_hook):
